@@ -1,9 +1,12 @@
 import argparse
+import sys
+
 from . import basketcase
 
 def main():
+    """Handle command-line script execution."""
+
     parser = argparse.ArgumentParser(description='Fetch resources from Instagram.')
-    parser.add_argument('-l', '--login', action='store_true', help='Attempt to authenticate (interactively)')
     parser.add_argument('input_file', type=argparse.FileType('r'), help='A list of URLs separated by newline characters')
     args = parser.parse_args()
 
@@ -14,14 +17,15 @@ def main():
 
         if line:
             urls.add(line)
-
+    
     bc = basketcase.BasketCase()
 
-    if args.login:
-        bc.login()
+    if bc.authenticator.needs_authentication():
+        bc.authenticator.login()
 
     bc.fetch(urls)
 
-if __name__ == '__main__':
-    main()
+    return 0
 
+if __name__ == '__main__':
+    sys.exit(main())
